;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Loading this file installs CG/JS.
;; Please see readme.txt for more information
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(in-package :user)

(eval-when (compile eval load)
  (require :shell)
  (use-package :excl.shell))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; validate files

(let ((platform-file
       (directory
	(merge-pathnames
	 "PLATFORM-*"
	 (path-pathname *load-pathname*)))))
  (or platform-file
      (error "Could not find the PLATFORM file."))
  
  (when (> (length platform-file) 1)
    (error "There is more than one PLATFORM file: ~a." platform-file))
  (setq platform-file (car platform-file))
  
  (or (=~ "^PLATFORM-(.*)" (file-namestring platform-file))
      (error "Cannot parse the PLATFORM file."))
  
  (let ((expected-platform $1)
	(current-platform
	 (format nil "~a~a" (symbol-name sys::.os.) #+smp "smp" #-smp "")))
    (or (string-equal expected-platform current-platform)
	(error
	 "The current platform (~a) does not match the downloaded version (~a)."
	 current-platform expected-platform)))
  ;; We are on the correct platform, fall through...
  )

;; HTML files needed for the operation of CG/JS
;; (this variable's value is generated by build_cgjs.sh)
(defvar *html-files* '("cgjs.html" "ssl-not-found.html" "browser-not-supported.html" ))

(defvar *extra-files*)
(setq *extra-files* nil)

(dolist (file *html-files*)
  (setq file (merge-pathnames file *load-pathname*))
  (or (probe-file file)
      (error "~a does not exist." file))
  (push file *extra-files*))
;; All *html-files* exist...

;; These two are directories but the pathname is specified as
;; a file, so merging works below.
(defvar *cg2js-directory* (merge-pathnames "code.cg2js" *load-pathname*))
(defvar *idejs-directory* (merge-pathnames "code.idejs" *load-pathname*))

(dolist (d (list *cg2js-directory* *idejs-directory*))
  (or (probe-file d)
      (error "~a does not exist." d)))

;; MD5 checksums of the incoming files
;; (this variable's value is generated by build_cgjs.sh)
(defvar *checksums* 
'(
(#x194b4c04aa9daa0d750dc536fb450429 . "./code.cg2js/cg-bitmap-pane-clipboard.fasl")
(#xf5e5b7b886242aec0f959aa1e4728866 . "./code.cg2js/cg-drag-and-drop.fasl")
(#xd40ec998bbd75a7b199b3ebaa0836db3 . "./code.cg2js/cg-toolbar.fasl")
(#xcc4deac2156f57344c0606269241b53e . "./code.cg2js/cg-chart-or-plot.fasl")
(#xab7b5f0a9e70100d7739949edc44b166 . "./code.cg2js/cg-rich-edit-pane-printing.fasl")
(#x46e6dd6b2e25d36dee9297ff55b5c5ff . "./code.cg2js/cg-class-grid.fasl")
(#xf935c983035bfbfc8140d0b30e841d92 . "./code.cg2js/cg-tray.fasl")
(#x7db7a10655f7c0bc421c6c610b41050b . "./code.cg2js/cg-gesture-emulation.fasl")
(#x1f9a5db037cf2c0dee7284faf43a5d04 . "./code.cg2js/cg-class-support.fasl")
(#xbc1b942fab0ff6704844243e3bf61e09 . "./code.cg2js/cg-multi-line-lisp-text.fasl")
(#x062cefd4ea431d3e7bfb870c293a2bc3 . "./code.cg2js/cg-dropping-outline.fasl")
(#xe7057147c26bd5ac16cb33473a30ccfa . "./code.cg2js/cg-rich-edit-pane.fasl")
(#x0a02806b28f15ce89e70088fce9db699 . "./code.cg2js/cg-choice-list.fasl")
(#x33e5b98a7264e6c25e2d2188ebec997c . "./code.cg2js/cg-grid-widget-drag-and-drop.fasl")
(#xa1059fc6969610cbaab9b598ddec644e . "./code.cg2js/cg-picture-widget-palette.fasl")
(#x7506248e63c1566f641e3649e3adc2f7 . "./code.cg2js/cg-timer.fasl")
(#xc40b1bc080c03911dd707ff64d3728a4 . "./code.cg2js/cg-directory-dialog.fasl")
(#xc5d95a8604ff2a5f1fdca0c09fe3f691 . "./code.cg2js/cg-multi-picture-button-tooltip.fasl")
(#x755ddde293004ac52ec1c18eebd10a47 . "./code.cg2js/cg-outline-edit-in-place.fasl")
(#x2e5a7811e01092ed34a31f0d6bca619c . "./code.cg2js/cg-pixmap-rotate.fasl")
(#x95102d115e63341ab5d79c6065147ed1 . "./code.cg2js/cg-html-widget.fasl")
(#xf06119f57592126b85f916810a963ceb . "./code.cg2js/cg-selected-object.fasl")
(#x073462132cbdd6091a59c7fa23281461 . "./code.cg2js/cg-lamp.fasl")
(#x5f341400772184a229e1b6677a5c1bcb . "./code.cg2js/cg-scroll-bar.fasl")
(#xc7cc2a81435dd73fadf694c257a7c326 . "./code.cg2js/cg-cursor-pixmap.fasl")
(#x76e7222d32c28f91518d532571dadbbc . "./code.cg2js/cg-message-dialog.fasl")
(#x17174611ad2c692764f33bfd0bc56875 . "./code.cg2js/cg-dde-utils.fasl")
(#xf610d2be0cf80e337846bc91d8dfa766 . "./code.cg2js/cg-group-box.fasl")
(#x4240147d9a548490fee6f5d52e1d6c87 . "./code.cg2js/cg-find-string-dialog.fasl")
(#x86e3f508822924a047a0f59834498522 . "./code.cg2js/cg-split-bar.fasl")
(#x3da39bd706405bb38148c96d9ef92042 . "./code.cg2js/cg-radio-button.fasl")
(#x50bb3b54f873d945a799939d22529d00 . "./code.cg2js/cg-base.fasl")
(#xe5bdbdd1f49430177cd64f2c558402da . "./code.cg2js/cg-paren-matching.fasl")
(#x724b76b7d139805e6c2fac1e415d1b6b . "./code.cg2js/cg-graphics-context.fasl")
(#x1f4ddf6f8fdc7fe0ec7b19aa1060aedc . "./code.cg2js/cg-keyboard-shortcuts.fasl")
(#xb1a1b7277de52398d6279e366431bc31 . "./code.cg2js/cg-scroll-bar-mixin.fasl")
(#xf318f739cd9007b8b2936c8975162afb . "./code.cg2js/cg-plot-widget.fasl")
(#x345d1ef91040c4a06661ca239da831c3 . "./code.cg2js/cg-dev.fasl")
(#x2acd192259c56540eab7fe296b601ff3 . "./code.cg2js/cg-text-edit-pane.fasl")
(#xdd55db832f818acaa2272ea53337ee6f . "./code.cg2js/cg-tab-control.fasl")
(#xf408de0b9714ec8259a17c1a10d7138b . "./code.cg2js/cg-fill-texture.fasl")
(#x4db01f39828821b2ef3a457d32a13f07 . "./code.cg2js/cg-menu-tooltip.fasl")
(#x04708d73c029444b040b46f14c83c0d7 . "./code.cg2js/cg-trackbar.fasl")
(#x8a57ecb2748920ef47fd4b3dd63ec1a7 . "./code.cg2js/cg-nodes.fasl")
(#xafc579a57f024d37966d920cf3b5bbfb . "./code.cg2js/cg-common-control.fasl")
(#x71faa27f6a8189b2930f4b558a567ad3 . "./code.cg2js/cg-list-view.fasl")
(#xaf43c2319d66839dfe8794119403d63b . "./code.cg2js/cg-rich-edit.fasl")
(#x49635eb754e91ab16af55e49ac18e602 . "./code.cg2js/cg-project-window.fasl")
(#x2202487a09f9b4f64fb585e13a2248a7 . "./code.cg2js/cg-item-list.fasl")
(#x06deee6041d42e0dce538a922ac528f1 . "./code.cg2js/cg-multi-picture-button-drag-and-drop.fasl")
(#xef27797d003e052e85a9b1be00ab0946 . "./code.cg2js/cg-get-position.fasl")
(#xdf438da7d32341e667772c9b36c4bac5 . "./code.cg2js/cg-bitmap-pane.fasl")
(#x610dc5918393b1449e2dd2203373e9f4 . "./code.cg2js/cg-drawable.fasl")
(#x7dc987e2c415f6ab58f383c7221f8152 . "./code.cg2js/cg-lettered-menu.fasl")
(#x3298a19bd535b1acafed0583316f36f1 . "./code.cg2js/cg-multi-line-editable-text.fasl")
(#x0594d23b2df30748c0ddaf48183dd09c . "./code.cg2js/cg-html-dialog.fasl")
(#x7714ecf22f1ec258999ba6b583481ae3 . "./code.cg2js/cg-object-editor-layout.fasl")
(#x2fedcc9213ae8251474de2a5e84455a6 . "./code.cg2js/cg-utility-dialog.fasl")
(#xd57315feaae81cd64d7db4ad7b7cdb30 . "./code.cg2js/cg-pixmap-widget.fasl")
(#x1f2b63c83ec24a112ebcb03ca46aa0f7 . "./code.cg2js/cg-property.fasl")
(#x6160a1db25bc43281595b65f7203e3a8 . "./code.cg2js/cg-menu.fasl")
(#x89713d5d98c170028027243f66aa853e . "./code.cg2js/cg-clipboard.fasl")
(#x5d1ff226ea235d8eaf1faf6dd15f29c5 . "./code.cg2js/cg-toggling-widget.fasl")
(#x82aeb7743076d64863ecd7f51b97a6ef . "./code.cg2js/cg-rich-edit-pane-clipboard.fasl")
(#x741ee965d570960deebff7bc12e8afca . "./code.cg2js/cg-template-string.fasl")
(#xeec2ca421afba9533568f593bae54d3a . "./code.cg2js/cg-drag-and-drop-image.fasl")
(#x5475cc6fd1dd06e8473b2662c012c784 . "./code.cg2js/cg-os-window.fasl")
(#xf519bfdcc8443ae155d4deb583c2cc7b . "./code.cg2js/cg-grid-widget.fasl")
(#xb5346253de4fff1672d63cc7f97cfdea . "./code.cg2js/cg-picture-widget.fasl")
(#x8268e63dcdb23c5c9e85c1f6f9ffb39a . "./code.cg2js/cg-text-edit-pane-mark.fasl")
(#x4f476fa0ba47e482ca91e92e6545eb46 . "./code.cg2js/cg-static-text.fasl")
(#x22014ca35cfe43f4b1b600f7dd296892 . "./code.cg2js/cg-clipboard-stack.fasl")
(#x61182da11a3490599528033c81bfe79c . "./code.cg2js/cg-text-widget.fasl")
(#x0adba53c939d307878d04de3752e657c . "./code.cg2js/cg-calendar.fasl")
(#xc92bb00d951def1c0de354befa07072e . "./code.cg2js/cg-check-box.fasl")
(#xd04bb49e5f59988a481cea3ddf19a9dc . "./code.cg2js/cg-acache.fasl")
(#x6c2aca02745b6e2ec773250ca9d1333d . "./code.cg2js/cg-wrap-string.fasl")
(#x0200793ff713840d07a194eb1ba411ce . "./code.cg2js/cg-bitmap-stream.fasl")
(#x5fd2dc401d4a8ffa464cc080e65df375 . "./code.cg2js/cg-font-dialog.fasl")
(#xfa1470298ffe3e31a30929a1394cc4b3 . "./code.cg2js/cg-outline.fasl")
(#x20d756f17933911f562ef685b4262840 . "./code.cg2js/cg-shortcut-menu.fasl")
(#x210643c126e139c1eafb14bd56d7323d . "./code.cg2js/cg-status-bar.fasl")
(#xa1bc91c913440c487ed9a16909c07d9d . "./code.cg2js/cg-multi-picture-button.fasl")
(#xa8987340496776154a1ba3be26141d6c . "./code.cg2js/cg-hotspot.fasl")
(#xb531ce3fcbc1eb656a61e408cf2a85a1 . "./code.cg2js/cg-scaling-stream.fasl")
(#xc75713702f66e58248e40f03cde300bd . "./code.cg2js/cg-icon-pixmap.fasl")
(#xfd455f73b20680969a32a393b4b57269 . "./code.cg2js/cg-file-dialog.fasl")
(#x308c0a6455c2741018c5b63e50d5661d . "./code.cg2js/cg-color-dialog.fasl")
(#xfbcad118fb2001ad57c493c0432c369a . "./code.cg2js/cg-get-pixmap.fasl")
(#xe2341b17fa841feebdbdc841e014f893 . "./code.cg2js/cg-object-editor.fasl")
(#x4bcf78f236b40aa69be55c0e4d67739d . "./code.cg2js/cg-outline-drag-and-drop.fasl")
(#x5fb9e756884c8071a8b2d482fd82d2d5 . "./code.cg2js/cg-pixmap-file-io.fasl")
(#xa2aa0e50e151384f3bede4fe92abc1d1 . "./code.cg2js/cg-pixmap.fasl")
(#x04d92b1166be21c66b8c47055fbb2e00 . "./code.cg2js/cg-intersect.fasl")
(#x83d472928cc3a40c151c849d07da013e . "./code.cg2js/cg-scrolling-static-text.fasl")
(#xb6bb2a0752b1531b04e60f4b59863fa0 . "./code.cg2js/cg-icon.fasl")
(#xf57646733e032378ddc206c16c7a128e . "./code.cg2js/cg-yes-no-string.fasl")
(#xbb9cf00e63d3ac08a85c7ea74deb058b . "./code.cg2js/cg-text-or-combo.fasl")
(#xd5c9d43842b4c7a4941a4c3affa1f6c2 . "./code.cg2js/cg.fasl")
(#x392d61cba8b6fee62da935cfb4429733 . "./code.cg2js/cg-dialog-item.fasl")
(#x6b092ba5c25741a8789bef3b4f454b4c . "./code.cg2js/cg-drawable-clipboard.fasl")
(#xc9920b94dc56cefc429b82eb67e3352a . "./code.cg2js/cg-caret.fasl")
(#x078ac106747e0dff0657b56704107744 . "./code.cg2js/cg-editable-text.fasl")
(#xd7c082e1c525804ca61d1744aa27c9a3 . "./code.cg2js/cg-choose-printer.fasl")
(#xe7a40c69b5ee986e95c7b0cb207cae71 . "./code.cg2js/cg-yes-no-list.fasl")
(#x8bf9ff0c39019beabeed1965dec36dc9 . "./code.cg2js/cg-intersect-posbox.fasl")
(#xa59a1d6e801c2ab612e0769b7d5a1362 . "./code.cg2js/cg-tooltip.fasl")
(#x833e83285371b6f5456d77d4e8b89564 . "./code.cg2js/cg-class-slot-grid.fasl")
(#xcb9deabcb767c76ce91d2295481ecf7e . "./code.cg2js/cg-combo-box.fasl")
(#xe1239351f99ed3e5ed4ccc65b7c69724 . "./code.cg2js/cg-curve.fasl")
(#xd20b163c2c628e37db6cb1929c69e2c3 . "./code.cg2js/cg-web-browser.fasl")
(#x4905a66bdd265083c2949cccfac2676a . "./code.cg2js/cg-printing.fasl")
(#xe40ec30769d97afcb56c72ec088076ef . "./code.cg2js/cg-lisp-widget.fasl")
(#xc086c4ad8623b68ab16765c98ee0c4c7 . "./code.cg2js/cg-sample-file-menu.fasl")
(#xbfdbfb418c5792e33ce645a4c2d5082c . "./code.cg2js/cg-palette.fasl")
(#xa3397169f9af71ee5efb3f580b4f3c8c . "./code.cg2js/cg-os-widget.fasl")
(#x88d8dff9836558c442d41b132efcb0e5 . "./code.cg2js/cg-directory-dialog-os.fasl")
(#x714325624803b76ad8cbaee138a28c80 . "./code.cg2js/cg-pixmap-printing.fasl")
(#xae64261123e1ff3dc966255e5289d89d . "./code.cg2js/cg-button.fasl")
(#x3053abbc6805d47853362f35b9fd79cd . "./code.cg2js/cg-edit-in-place.fasl")
(#x098a2717c547c701036287311b0d5818 . "./code.cg2js/cg-text-edit-pane-file-io.fasl")
(#xe558586a809925d0cb2ce3bca367682e . "./code.cg2js/cg-comtab.fasl")
(#xb7aca30ac0e1ccb0f62328f0cc66af60 . "./code.cg2js/cg-string-dialog.fasl")
(#xf4a92294ad519e51cdc3c7753c12f6c0 . "./code.cg2js/cg-header-control.fasl")
(#xb5820edbd4f659d1dd49574b89f0d756 . "./code.cg2js/cg-clipboard-pixmap.fasl")
(#x35d732b5669228b6b9cd21c37b797c79 . "./code.cg2js/cg-up-down-control.fasl")
(#x6efaaa472e730d5e9e324fa58d2e11bf . "./code.cg2js/cg-layout.fasl")
(#x4a14fd5e599d45526a3ca7e31897e2e0 . "./code.cg2js/cg-chart-widget.fasl")
(#x299890f036d4b15b1182b40f2440ed3e . "./code.cg2js/cg-lisp-text.fasl")
(#xa2d20588420e700c80de3983f1307df0 . "./code.cg2js/cg-lisp-edit-pane.fasl")
(#x335d4ee07f023bf3f6eff123f7651701 . "./code.cg2js/cg-progress-indicator.fasl")
(#x6f290f5e3e1d7b4943881bb1b373e01f . "./code.idejs/ide-inspector.fasl")
(#x5d6a070a319c2570cf0c9f320706f187 . "./code.idejs/ide-grapher.fasl")
(#x28162a0d5f0d8cfb1f748caeb3a3d6fb . "./code.idejs/ide-base.fasl")
(#x89cf62e58a9b498e3538a14ed0c39559 . "./code.idejs/ide-keyshort.fasl")
(#x9b4e701e09c98cf9c88178b8d0a9da96 . "./code.idejs/ide-dev.fasl")
(#x6835f01409697635e6f362268713d51a . "./code.idejs/ide-class-browser.fasl")
(#xc92872e582a9f6b35de8912b392994a5 . "./code.idejs/ide-package-list.fasl")
(#x5271edd11efc2121ad5226a4bebc9a4b . "./code.idejs/ide-intro.fasl")
(#x89082717ff98d481e75f99224094591e . "./code.idejs/ide-class-grapher.fasl")
(#x45656dd2d1438857a5f7084a263692b7 . "./code.idejs/ide-window-list.fasl")
(#xa0773cb7297e7452be940707041b1496 . "./code.idejs/ide-find-definitions.fasl")
(#x2cfaab9b1d10f41fee7b37c3556f5d7d . "./code.idejs/ide-trace.fasl")
(#x6760184172646a4f6a98d74d1e4926fa . "./code.idejs/ide-editor.fasl")
(#x8ac4bcfa26395d9fc69487500fd43bf7 . "./code.idejs/ide-patch-dialog.fasl")
(#xdf080f991e6ef9fa06e622da18fe6c93 . "./code.idejs/ide-project.fasl")
(#x604fe41c63c84090b0971f5ae271adbc . "./code.idejs/ide.fasl")
(#x8de7a36245b5b45f6fe30f36f4beae8c . "./code.idejs/ide-apropos.fasl")
(#xbc7374637235c01e4a30209193718270 . "./code.idejs/ide-acache.fasl")
(#x9766ff72ee40c356141c76a28be2d62e . "./code.idejs/ide-clipboard.fasl")
(#x438568fd1be8d3ab295819a1fd05235a . "./code.idejs/ide-process-browser.fasl")
(#x5457d084e6d0df83c42dab9fc8ed93da . "./code.idejs/ide-find-in-files.fasl")
(#xcde405b5b2ca470536db600d7c50443c . "./code.idejs/ide-form.fasl")
(#x820cfec391c44a797efe11b5dfc5471b . "./code.idejs/ide-navigator.fasl")
(#xb19a66ec109be5a69fb5293c577fc104 . "./cgjs.html")
(#x34779e5d4bbb71d45bf63f88fac54100 . "./ssl-not-found.html")
(#x90c6d2a65504d45266ad9fa3a49be2f9 . "./browser-not-supported.html"))
 )

(let ((files-ok
       (dolist (checksum *checksums* t)
	 (when (/= (car checksum)
		   (md5-file
		    (merge-pathnames (cdr checksum) *load-pathname*)))
	   (return nil)))))
  (cond
   ((not files-ok)
    (error "The extracted files failed the checksum test.  ~
Please download and/or extract again."))
   (t
    (format t "Checksums on files are OK...~%"))))

;; We have validated all the files are there...

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; check for needed patches

(eval-when (compile eval load) (require :build))

(defvar *required-patches* '(#+macosx ("build" . 3)))

(dolist (required-patch *required-patches*)
  (let ((existing-patch (assoc (car required-patch)
			    (cdr (assoc :system sys::*patches*))
			    :test #'string=)))
    (when (null existing-patch)
      (error "Could not find patch info for the ~s module."
	     (car required-patch)))
    (when (not (>= (second existing-patch) (cdr required-patch)))
      ;; The build patch number is NOT >= to the one we require
      (error "~
Expected version ~d of ~s but have version ~d.  Please update ~
your lisp with update.~a and then do the CG/JS installation again."
	     (cdr required-patch) (car required-patch)
	     (second existing-patch)
	     #+mswindows "exe"
	     #-mswindows "sh"))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; copy files

(defun copy (source dest)
  (cond
   ((file-directory-p source)
    (format t "Copy directory ~a~%" (enough-namestring source))
    (copy-directory source dest :quiet t))
   (t
    (format t "Copy file ~a~%" (enough-namestring source))
    (sys:copy-file source dest :verbose nil))))

(defvar *sys* (translate-logical-pathname (pathname "sys:")))

(cond
 ((excl::pathname-equalp (truename *sys*)
			 (path-pathname *load-truename*))
  (format t "Files are already in place, no copying requiring.~%"))
 (t ;; copy files, replacing them with new ones if they already exist
  (let (dest)
    (dolist (from *extra-files*)
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      (when (probe-file dest) (delete-file dest))
      (copy from dest))
    
    (dolist (from (list *cg2js-directory* *idejs-directory*))
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      ;; now make it a directory pathname
      (setq dest (pathname-as-directory dest))

      (when (probe-file dest) (delete-directory-and-files dest))
      (copy (pathname-as-directory from) dest)))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; update develenv.cl to load CG/JS before the original version of CG

(defvar *setup-cgjs-loading* "sys:setup-cgjs-loading.cl")

;; Because users might use an ANSI lisp to install, have to make sure
;; the resulting file can be loaded into an ANSI and Modern lisp.
(with-open-file (s *setup-cgjs-loading* :direction :output
		 :if-exists :supersede)
  (format s "~
;; This file was created by install-cgjs.cl.
;; Please do not edit it.

")
  (dolist (dir (list "code.cg2js/" "code.idejs/"))
    (format s "
(let ((path (make-pathname
	     :type \"fasl\"
	     :directory (pathname-directory
			 (merge-pathnames
			  ~s
			  (translate-logical-pathname \"sys:\"))))))
  (format t \";; *require-search-list*: adding: ~~s~%\" path)
  (push path sys:*require-search-list*))

"
	    dir)))

(defvar *develenv.cl* (pathname "sys:develenv.cl"))

(when (not (probe-file *develenv.cl*))
  (setf (file-contents *develenv.cl*)
    ";; This file is loaded before images are rebuilt with update.sh/update.exe

"))

(let ((contents (file-contents *develenv.cl*)))
  (cond
   ((match-re
     (format nil "^#\\|\\|# \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl already correctly loads CG/JS.~%"))
   ((match-re
     (format nil "^#\\+ignore \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl: CG/JS disabled; will enable.~%")
    (setf (file-contents *develenv.cl*)
      (replace-re  contents
		  (format nil "^#\\+ignore *\\(load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  (format nil "#||# (load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  :multiple-lines t
		  :count 1)))
   (t
    (format t "develenv.cl: adding CG/JS initialization.~%")
    (setf (file-contents *develenv.cl*)
      (concatenate 'simple-string
	contents
	(format nil "~

;; To disable the use of CG/JS and go back to the originally released
;; (and possibly patched) version of CG/IDE, change the #||# to
;; #+ignore on the following line and the rebuild images by running
;; update.sh or update.exe, depending on your platform:
#||# (load \"sys:~a\")~%~%"
		(file-namestring *setup-cgjs-loading*)))))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; success!

(let ((msg (format nil "~
CG/JS installation successful!

NOTE: to use CG/JS you must rebuild images by running 'update.~a'
      in the Allegro CL directory (~a)."
		   #+mswindows "exe"
		   #-mswindows "sh"
		   *sys*)))
  #-mswindows (format t "~&~%~a~%" msg)
  #+mswindows (excl::internal-message-box msg "CG/JS Installation" :type :ok))
